==> mx-packageinstaller-pkglist_19.07.06.tar.xz: mx-packageinstaller-pkglist/german_LO.pm <==
<?xml version="1.0"?>
<app>

<category>
Language
</category>

<name>
German_Libreoffice
</name>

<description>
   <am>German Language Meta-Package for LibreOffice</am>
   <ar>German Language Meta-Package for LibreOffice</ar>
   <bg>German Language Meta-Package for LibreOffice</bg>
   <ca>Meta-paquet d'alemany per LibreOffice</ca>
   <cs>German Language Meta-Package for LibreOffice</cs>
   <da>Tysk sprog-metapakke til LibreOffice</da>
   <de>Deutsches Meta-Paket für LibreOffice</de>
   <el>LibreOffice στα γερμανικά</el>
   <en>German Language Meta-Package for LibreOffice</en>
   <es>German Language Meta-Package for LibreOffice</es>
   <et>German Language Meta-Package for LibreOffice</et>
   <eu>German Language Meta-Package for LibreOffice</eu>
   <fa>German Language Meta-Package for LibreOffice</fa>
   <fi>German Language Meta-Package for LibreOffice</fi>
   <fr>Méta-paquet langue allemande pour LibreOffice</fr>
   <he_IL>German Language Meta-Package for LibreOffice</he_IL>
   <hi>German Language Meta-Package for LibreOffice</hi>
   <hr>German Language Meta-Package for LibreOffice</hr>
   <hu>German Language Meta-Package for LibreOffice</hu>
   <id>German Language Meta-Package for LibreOffice</id>
   <is>German Language Meta-Package for LibreOffice</is>
   <it>Meta-pacchetto della lingua tedesca per LibreOffice</it>
   <ja_JP>German Language Meta-Package for LibreOffice</ja_JP>
   <ja>German Language Meta-Package for LibreOffice</ja>
   <kk>German Language Meta-Package for LibreOffice</kk>
   <ko>German Language Meta-Package for LibreOffice</ko>
   <lt>German Language Meta-Package for LibreOffice</lt>
   <mk>German Language Meta-Package for LibreOffice</mk>
   <nb>German Language Meta-Package for LibreOffice</nb>
   <nl>Duitse Taal Meta-Pakket voor LibreOffice</nl>
   <pl>Niemiecki metapakiet językowy dla LibreOffice</pl>
   <pt_BR>Alemão Meta-Pacote de Idioma para LibreOffice</pt_BR>
   <pt>Alemão Meta-Pacote de Idioma para LibreOffice</pt>
   <ro>German Language Meta-Package for LibreOffice</ro>
   <ru>German Language Meta-Package for LibreOffice</ru>
   <sk>German Language Meta-Package for LibreOffice</sk>
   <sl>German Language Meta-Package for LibreOffice</sl>
   <sq>German Language Meta-Package for LibreOffice</sq>
   <sr>German Language Meta-Package for LibreOffice</sr>
   <sv>Tyskt Språk Meta-Paket för LibreOffice</sv>
   <tr>German Language Meta-Package for LibreOffice</tr>
   <uk>German Language Meta-Package for LibreOffice</uk>
   <zh_CN>German Language Meta-Package for LibreOffice</zh_CN>
   <zh_TW>German Language Meta-Package for LibreOffice</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>

</preinstall>

<install_package_names>
libreoffice-calc
libreoffice-draw
libreoffice-impress
libreoffice-math
libreoffice-writer
libreoffice-l10n-de
libreoffice-help-de
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
libreoffice-calc
libreoffice-draw
libreoffice-impress
libreoffice-math
libreoffice-writer
libreoffice-l10n-de
libreoffice-help-de
</uninstall_package_names>
</app>

==> mx-packageinstaller-pkglist_19.09.01.tar.xz: mx-packageinstaller-pkglist/german_LO.pm <==
<?xml version="1.0"?>
<app>

<category>
Language
</category>

<name>
German_Libreoffice
</name>

<description>
   <am>German Language Meta-Package for LibreOffice</am>
   <ar>German Language Meta-Package for LibreOffice</ar>
   <bg>German Language Meta-Package for LibreOffice</bg>
   <ca>Meta-paquet d'alemany per LibreOffice</ca>
   <cs>German Language Meta-Package for LibreOffice</cs>
   <da>Tysk sprog-metapakke til LibreOffice</da>
   <de>Deutsches Meta-Paket für LibreOffice</de>
   <el>LibreOffice στα γερμανικά</el>
   <en>German Language Meta-Package for LibreOffice</en>
   <es>Meta-Paquete de Idioma Alemán para LibreOffice</es>
   <et>German Language Meta-Package for LibreOffice</et>
   <eu>German Language Meta-Package for LibreOffice</eu>
   <fa>German Language Meta-Package for LibreOffice</fa>
   <fi>German Language Meta-Package for LibreOffice</fi>
   <fr>Méta-paquet langue allemande pour LibreOffice</fr>
   <he_IL>German Language Meta-Package for LibreOffice</he_IL>
   <hi>German Language Meta-Package for LibreOffice</hi>
   <hr>German Language Meta-Package for LibreOffice</hr>
   <hu>German Language Meta-Package for LibreOffice</hu>
   <id>German Language Meta-Package for LibreOffice</id>
   <is>German Language Meta-Package for LibreOffice</is>
   <it>Meta-pacchetto della lingua tedesca per LibreOffice</it>
   <ja_JP>German Language Meta-Package for LibreOffice</ja_JP>
   <ja>German Language Meta-Package for LibreOffice</ja>
   <kk>German Language Meta-Package for LibreOffice</kk>
   <ko>German Language Meta-Package for LibreOffice</ko>
   <lt>German Language Meta-Package for LibreOffice</lt>
   <mk>German Language Meta-Package for LibreOffice</mk>
   <nb>German Language Meta-Package for LibreOffice</nb>
   <nl>Duitse Taal Meta-Pakket voor LibreOffice</nl>
   <pl>Niemiecki metapakiet językowy dla LibreOffice</pl>
   <pt_BR>Alemão Meta-Pacote de Idioma para LibreOffice</pt_BR>
   <pt>Alemão Meta-Pacote de Idioma para LibreOffice</pt>
   <ro>German Language Meta-Package for LibreOffice</ro>
   <ru>German Language Meta-Package for LibreOffice</ru>
   <sk>German Language Meta-Package for LibreOffice</sk>
   <sl>German Language Meta-Package for LibreOffice</sl>
   <sq>German Language Meta-Package for LibreOffice</sq>
   <sr>German Language Meta-Package for LibreOffice</sr>
   <sv>Tyskt Språk Meta-Paket för LibreOffice</sv>
   <tr>German Language Meta-Package for LibreOffice</tr>
   <uk>German Language Meta-Package for LibreOffice</uk>
   <zh_CN>German Language Meta-Package for LibreOffice</zh_CN>
   <zh_TW>German Language Meta-Package for LibreOffice</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>

</preinstall>

<install_package_names>
libreoffice-calc
libreoffice-draw
libreoffice-impress
libreoffice-math
libreoffice-writer
libreoffice-l10n-de
libreoffice-help-de
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
libreoffice-calc
libreoffice-draw
libreoffice-impress
libreoffice-math
libreoffice-writer
libreoffice-l10n-de
libreoffice-help-de
</uninstall_package_names>
</app>
